' global quantities for wire properties program, WIREPROP.EXE, version 1.0

'---------------------------------------------------------------
' FORM DESIGN CONSIDERATIONS - If this program is be used on
'  systems with video systems set for resolutions lower than
'  1024 x 768, many forms will have be designed to avoid
'  portions of some forms being outside the viewable area.
'
' This program was designed on a 1024 x 768 video system and
'  it is felt by the author that most computers in use today
'  (2003) support this resolution.
'
' For example, for 640 x 480, dimension limits are shown below:
'  max width = 9615 (scale width = 9495) @ left = 0
'  max height = 6810 (scale height = 6810) @ top = 0
'  client area limits:
'    width = 9495
'    left = 60
'    height = 6405
'    top = 345
'
' All forms could have been designed to auto-resize themselves
'  but this would have considerably complicated the program
'  design and increased the executable file size.
'
'---------------------------------------------------------------
'
' Dimension tables for different screen resolutions (in twips):
'
'-----------------------------------------------------------
'   Dimension   | 1280x1024 | 1024x768 | 800x600 | 640x480 |
'---------------|-----------|----------|---------|---------|
' Form Left     |       0   |       0  |      0  |      0  |
' Form Width    |   19230   |   15405  |  12015  |   9615  |
' Form Top      |       0   |       0  |      0  |      0  |
' Form Height   |   14970   |   11115  |   8580  |   6810  |
' Client Left   |      60   |      60  |     60  |     60  |
' Client Width  |   19110   |   15285  |  11895  |   9495  |
' Client Top    |     345   |     345  |    345  |    345  |
' Client Height |   14565   |   10710  |   8175  |   6405  |
' Scale Left    |       0   |       0  |      0  |      0  |
' Scale Width   |   19110   |   15285  |  11895  |   9495  |
' Scale Top     |       0   |       0  |      0  |      0  |
' Scale Height  |   14565   |   10710  |   8175  |   6405  |
' Scale Mode    |  1-twip   |  1-twip  | 1-twip  | 1-twip  |
'-----------------------------------------------------------

' dimension arrays, constants, and variables

Global WIRE(57, 12) As Single
                        ' 54 AWG sizes between #4/0 and #50
                        ' 57 SWG sizes between #7/0 and #50
                        ' array elements
                        ' WIRE(W,0) = wire size (AWG & SWG)
                        ' WIRE(W,1) = AWG wire diameter (inches)
                        ' WIRE(W,2) = AWG wire area (circ. mils)
                        ' WIRE(W,3) = AWG copper resistance (ohms/1000')
                        ' WIRE(W,4) = AWG aluminum resistance (ohms/1000')
                        ' WIRE(W,5) = AWG copper weight (lbs/1000')
                        ' WIRE(W,6) = AWG aluminum weight (lbs/1000')
                        ' WIRE(W,7) = SWG wire diameter (inches)
                        ' WIRE(W,8) = SWG wire area (circ. mils)
                        ' WIRE(W,9) = SWG copper resistance (ohms/1000')
                        ' WIRE(W,10) = SWG aluminum resistance (ohms/1000')
                        ' WIRE(W,11) = SWG copper weight (lbs/1000')
                        ' WIRE(W,12) = SWG aluminum weight (lbs/1000')

Global DIAM(1) As String    ' input wire diameter in inches
                            ' DIAM(0) = unused
                            ' DIAM(1) = input

Global I As Integer         ' loop counter

Global K As Double          ' diameter ratio (constant)

Global NewLine As String    ' newline code

Global Q As Single          ' value of wire diameter input

Sub CenterForm (frm As Form)
    ' subprogram to center forms on the screen

    ' included to accommodate different screen resolutions
    ' hard-coded locations are valid only for design
    '  environment

        ' dimension local variables
    Dim LeftSide As Integer
    Dim TopOfForm As Integer

        ' determine location of left side of form
    LeftSide = (Screen.Width - frm.Width) / 2

        ' determine location of top of form
    TopOfForm = (Screen.Height - frm.Height) / 2

        ' position form on screen
    frm.Move LeftSide, TopOfForm

End Sub

Sub LoadWireArray ()
    ' fill WIRE array with wire characteristics

        ' declare local variables
    Dim Area As Single, ResCUA As Single, ResALA As Single
    Dim ResCUS As Single, ResALS As Single
    Dim CUWTA As Single, ALWTA As Single, CUWTS As Single, ALWTS As Single
    Dim K As Double
    Dim N As Integer, V As Integer, X As Integer
    Dim D As Single, U As Single, W As Single

    ' -------------------------
    ' Wire Sizes (AWG & SWG)
    ' -------------------------

        For I = 0 To 56
            WIRE(I, 0) = I
        Next I

    ' ---------------------------------------------------------------------
    '                        Basis of AWG Wire Sizes
    '
    ' AWG system:  geometric progression of 39 wire sizes from #4/0 to #36
    '              #4/0 = 0.4600" diameter
    '              #36  = 0.0050" diameter
    '              number of sizes (increments) = 39 between #4/0 and #36
    ' AWG Wire Size = (0.4600 / 0.0050) ^ (1 / 39)
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-19, Section 4-80.
    ' ---------------------------------------------------------------------

    ' -------------------------
    ' AWG Diameters
    ' -------------------------
    '
    ' N = AWG size + 3 (3 added to allow for sizes #2/0, #3/0, and #4/0)
    ' K = increment multiplier = (0.46/0.005) ^ (1/39) = 92 ^ (1/39)
    ' D = diameter = 0.46 / (K ^ N)
    '
        K = (.46 / .005) ^ (1 / 39)

        For I = 0 To 56
            D = .46 / (K ^ I)
            '
            ' round D to four decimal places
            '
            U = D * 10000
            V = Int(U + .5)     ' round U to nearest whole number V
            W = V / 10000       ' W is rounded decimal
            D = W
            WIRE(I, 1) = D
        Next I

    ' -------------------------
    ' AWG Areas
    ' -------------------------
    '
    ' Area = (D * 1000) ^ 2 = (WIRE(I, 1) * 1000) ^ 2 circular mils
    '
        For I = 0 To 3                      ' #4/0 thru #1/0
            '
            ' round Area to 4 decimal places
            '
            Area = (WIRE(I, 1) ^ 2) * 10000
            X = Int(Area + .5)
            Area = (X / 10000) * 1000000
            WIRE(I, 2) = Area
        Next I

        For I = 4 To 23                     ' #1 thru #20
            '
            ' round Area to 5 decimal places
            '
            Area = (WIRE(I, 1) ^ 2) * 100000
            X = Int(Area + .5)
            Area = (X / 100000) * 1000000
            WIRE(I, 2) = Area
        Next I

        For I = 24 To 33                    ' #21 thru #30
            '
            ' round Area to 6 decimal places
            '
            Area = (WIRE(I, 1) ^ 2) * 1000000
            X = Int(Area + .5)
            Area = (X / 1000000) * 1000000
            WIRE(I, 2) = Area
        Next I

        For I = 34 To 41                    ' #31 thru #38
            '
            ' round Area to 7 decimal places
            '
            Area = (WIRE(I, 1) ^ 2) * 10000000
            X = Int(Area + .5)
            Area = (X / 10000000) * 1000000
            WIRE(I, 2) = Area
        Next I

        WIRE(42, 2) = 12.2                  ' #39

        For I = 43 To 47                    ' #40 thru #44
            Area = (WIRE(I, 1) * 1000) ^ 2
            WIRE(I, 2) = Area
        Next I

        ' To correctly compute the areas of #45 AWG and smaller,
        '  the diameter must be rounded to 4 decimal places

        For I = 48 To 56
            D = .46 / (K ^ I)
            U = D * 10000
            V = Int(U + .5)
            W = V / 10000
            D = W
            Area = (D * 1000) ^ 2
            WIRE(I, 2) = Area
        Next I

    ' -------------------------
    ' AWG Resistance (copper)
    ' -------------------------
    '
    ' Resistance = 10574 / Area (ohms per 1000 feet @ 68 degrees F)
    '
        For I = 0 To 56
            ResCUA = 10574 / WIRE(I, 2)
            WIRE(I, 3) = ResCUA
        Next I

    ' -------------------------
    ' AWG Resistance (aluminum)
    ' -------------------------
    '
    ' Resistance = 16920 / Area (ohms per 1000 feet @ 68 degrees F)
    ' Resistance of aluminum is approx. 1.6 times that of copper
    '
        For I = 0 To 56
            ResALA = 16920 / WIRE(I, 2)
            WIRE(I, 4) = ResALA
        Next I

    ' -------------------------
    ' AWG Weight (copper)
    ' -------------------------
    '
    ' Weight = 3027 * (Diam)^2 lb/1000 feet @ 68 degrees F  (Diam is in inches)
    '
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-4, Section 4-7.
    '
        For I = 0 To 56
            N = I + 3
            CUWTA = ((WIRE(I, 1) ^ 2) * 3027)
            WIRE(I, 5) = CUWTA
        Next I

    ' -------------------------
    ' AWG Weight (aluminum)
    ' -------------------------
    '
    ' Weight = 920.33 * (Diam)^2 lb/1000 feet @ 68 degrees F  (Diam is in inches)
    '
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-4, Section 4-10.
    '
        For I = 0 To 56
            N = I + 3
            ALWTA = ((WIRE(I, 1) ^ 2) * 920.33)
            WIRE(I, 6) = ALWTA
        Next I

    ' ---------------------------------------------------------------------
    '                             SWG Wire Sizes
    '
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-40, Table 4-10.
    ' ---------------------------------------------------------------------

    ' -------------------------
    ' SWG Diameters
    ' -------------------------

        WIRE(0, 7) = .5                         ' #7/0
        WIRE(1, 7) = .464                       ' #6/0
        WIRE(2, 7) = .432                       ' #5/0
        WIRE(3, 7) = .4                         ' #4/0
        WIRE(4, 7) = .372                       ' #3/0
        WIRE(5, 7) = .348                       ' #2/0
        WIRE(6, 7) = .324                       ' #1/0
        WIRE(7, 7) = .3                         ' #1
        WIRE(8, 7) = .276                       ' #2
        WIRE(9, 7) = .252                       ' #3
        WIRE(10, 7) = .232                      ' #4
        WIRE(11, 7) = .212                      ' #5
        WIRE(12, 7) = .192                      ' #6
        WIRE(13, 7) = .176                      ' #7
        WIRE(14, 7) = .16                       ' #8
        WIRE(15, 7) = .144                      ' #9
        WIRE(16, 7) = .128                      ' #10
        WIRE(17, 7) = .116                      ' #11
        WIRE(18, 7) = .104                      ' #12
        WIRE(19, 7) = .092                      ' #13
        WIRE(20, 7) = .08                       ' #14
        WIRE(21, 7) = .072                      ' #15
        WIRE(22, 7) = .064                      ' #16
        WIRE(23, 7) = .056                      ' #17
        WIRE(24, 7) = .048                      ' #18
        WIRE(25, 7) = .04                       ' #19
        WIRE(26, 7) = .036                      ' #20
        WIRE(27, 7) = .032                      ' #21
        WIRE(28, 7) = .028                      ' #22
        WIRE(29, 7) = .024                      ' #23
        WIRE(30, 7) = .022                      ' #24
        WIRE(31, 7) = .02                       ' #25
        WIRE(32, 7) = .018                      ' #26
        WIRE(33, 7) = .0164                     ' #27
        WIRE(34, 7) = .0148                     ' #28
        WIRE(35, 7) = .0136                     ' #29
        WIRE(36, 7) = .0124                     ' #30
        WIRE(37, 7) = .0116                     ' #31
        WIRE(38, 7) = .0108                     ' #32
        WIRE(39, 7) = .01                       ' #33
        WIRE(40, 7) = .0092                     ' #34
        WIRE(41, 7) = .0084                     ' #35
        WIRE(42, 7) = .0076                     ' #36
        WIRE(43, 7) = .0068                     ' #37
        WIRE(44, 7) = .006                      ' #38
        WIRE(45, 7) = .0052                     ' #39
        WIRE(46, 7) = .0048                     ' #40
        WIRE(47, 7) = .0044                     ' #41
        WIRE(48, 7) = .004                      ' #42
        WIRE(49, 7) = .0036                     ' #43
        WIRE(50, 7) = .0032                     ' #44
        WIRE(51, 7) = .0028                     ' #45
        WIRE(52, 7) = .0024                     ' #46
        WIRE(53, 7) = .002                      ' #47
        WIRE(54, 7) = .0016                     ' #48
        WIRE(55, 7) = .0012                     ' #49
        WIRE(56, 7) = .001                      ' #50

    ' -------------------------
    ' SWG Areas
    ' -------------------------

        WIRE(0, 8) = 250000                     ' #7/0
        WIRE(1, 8) = 215000                     ' #6/0
        WIRE(2, 8) = 186600                     ' #5/0
        WIRE(3, 8) = 160000                     ' #4/0
        WIRE(4, 8) = 138400                     ' #3/0
        WIRE(5, 8) = 121100                     ' #2/0
        WIRE(6, 8) = 105000                     ' #1/0
        WIRE(7, 8) = 90000                      ' #1
        WIRE(8, 8) = 76180                      ' #2
        WIRE(9, 8) = 63500                      ' #3
        WIRE(10, 8) = 53820                     ' #4
        WIRE(11, 8) = 44940                     ' #5
        WIRE(12, 8) = 36860                     ' #6
        WIRE(13, 8) = 30980                     ' #7
        WIRE(14, 8) = 25600                     ' #8
        WIRE(15, 8) = 20740                     ' #9
        WIRE(16, 8) = 16380                     ' #10
        WIRE(17, 8) = 13460                     ' #11
        WIRE(18, 8) = 10820                     ' #12
        WIRE(19, 8) = 8464                      ' #13
        WIRE(20, 8) = 6400                      ' #14
        WIRE(21, 8) = 5184                      ' #15
        WIRE(22, 8) = 4096                      ' #16
        WIRE(23, 8) = 3136                      ' #17
        WIRE(24, 8) = 2304                      ' #18
        WIRE(25, 8) = 1600                      ' #19
        WIRE(26, 8) = 1296                      ' #20
        WIRE(27, 8) = 1024                      ' #21
        WIRE(28, 8) = 784                       ' #22
        WIRE(29, 8) = 576                       ' #23
        WIRE(30, 8) = 484                       ' #24
        WIRE(31, 8) = 400                       ' #25
        WIRE(32, 8) = 324                       ' #26
        WIRE(33, 8) = 269                       ' #27
        WIRE(34, 8) = 219                       ' #28
        WIRE(35, 8) = 185                       ' #29
        WIRE(36, 8) = 153.8                     ' #30
        WIRE(37, 8) = 134.6                     ' #31
        WIRE(38, 8) = 116.6                     ' #32
        WIRE(39, 8) = 100                       ' #33
        WIRE(40, 8) = 84.64                     ' #34
        WIRE(41, 8) = 70.56                     ' #35
        WIRE(42, 8) = 57.76                     ' #36
        WIRE(43, 8) = 46.24                     ' #37
        WIRE(44, 8) = 36                        ' #38
        WIRE(45, 8) = 27.04                     ' #39
        WIRE(46, 8) = 23.04                     ' #40
        WIRE(47, 8) = 19.36                     ' #41
        WIRE(48, 8) = 16                        ' #42
        WIRE(49, 8) = 12.96                     ' #43
        WIRE(50, 8) = 10.24                     ' #44
        WIRE(51, 8) = 7.84                      ' #45
        WIRE(52, 8) = 5.76                      ' #46
        WIRE(53, 8) = 4                         ' #47
        WIRE(54, 8) = 2.56                      ' #48
        WIRE(55, 8) = 1.44                      ' #49
        WIRE(56, 8) = 1                         ' #50

    ' -------------------------
    ' SWG Resistance (copper)
    ' -------------------------
    '
    ' Resistance = 10574 / Area (ohms per 1000 feet @ 68 degrees F)
    '
        For I = 0 To 56
            ResCUS = 10574 / WIRE(I, 8)
            WIRE(I, 9) = ResCUS
        Next I

    ' -------------------------
    ' SWG Resistance (aluminum)
    ' -------------------------
    '
    ' Resistance = 16920 / Area (ohms per 1000 feet @ 68 degrees F)
    ' Resistance of aluminum is approx. 1.6 times that of copper
    '
        For I = 0 To 56
            ResALS = 16920 / WIRE(I, 8)
            WIRE(I, 10) = ResALS
        Next I

    ' -------------------------
    ' SWG Weight (copper)
    ' -------------------------
    '
    ' Weight = 3027 * (Diam)^2 lb/1000 feet @ 68 degrees F  (Diam is in inches)
    '
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-4, Section 4-7.
    '
        For I = 0 To 56
            N = I + 3
            CUWTS = ((WIRE(I, 7) ^ 2) * 3027)
            WIRE(I, 11) = CUWTS
        Next I

    ' -------------------------
    ' SWG Weight (aluminum)
    ' -------------------------
    '
    ' Weight = 920.33 * (Diam)^2 lb/1000 feet @ 68 degrees F  (Diam is in inches)
    '
    ' Reference:  Standard Handbook for Electrical Engineers, Tenth
    '             Edition, 1968, Page 4-4, Section 4-10.
    '
        For I = 0 To 56
            N = I + 3
            ALWTS = ((WIRE(I, 7) ^ 2) * 920.33)
            WIRE(I, 12) = ALWTS
        Next I

End Sub

Sub Main ()
    ' wire properties program starting point
    frmWireMain.Show
    LoadWireArray           ' load wire array with values
End Sub

Sub ProgramTitle (frm As Form)
    ' caption property for all forms - placed here
    '  to make it easy to change all forms at once

        ' leading space added for readability
    frm.Caption = " WIRE PROPERTIES - Version 1.0"

End Sub

